@@ -1,7 +1,12 @@
+#include <sys/ioctl.h>
+#include <fcntl.h>
+#include <stdlib.h>
+#include <unistd.h>
 #include <stdio.h>
-#include <sys/fcntl.h>
-#include <cryptfs.h>
 
+#include <fist.h>
+
+int
 main(int argc, char *argv[])
 {
   int fd, ret, val = 0;
